# <span class="badge package-variant-panelcfg"></span> nodegraph

## Objects

 * <span class="badge object-type-class"></span> [ArcOption](./object-ArcOption.md)
 * <span class="badge object-type-class"></span> [EdgeOptions](./object-EdgeOptions.md)
 * <span class="badge object-type-class"></span> [NodeOptions](./object-NodeOptions.md)
 * <span class="badge object-type-class"></span> [Options](./object-Options.md)
## Builders

 * <span class="badge builder"></span> [ArcOption](./builder-ArcOption.md)
 * <span class="badge builder"></span> [EdgeOptions](./builder-EdgeOptions.md)
 * <span class="badge builder"></span> [NodeOptions](./builder-NodeOptions.md)
 * <span class="badge builder"></span> [Panel](./builder-Panel.md)
## Functions

### <span class="badge function"></span> variant_config

variant_config returns the configuration related to nodegraph panels.

This configuration describes how to unmarshal it, convert it to code, …

```python
def variant_config() -> variants.PanelcfgConfig
```

